@@ -1,36 +1,31 @@
 import sys, os
-try:
-    from setuptools.extension import Extension
-except ImportError:
-    from distutils.extension import Extension
+from distutils.core import Extension
 
 try:
-    from Pyrex.Distutils import build_ext as build_pyx
-    PYREX_INSTALLED = True
+    from Cython.Distutils import build_ext as build_pyx
+    import Cython.Compiler.Version
+    print("Building with Cython %s." % Cython.Compiler.Version.version)
+    CYTHON_INSTALLED = True
 except ImportError:
-    PYREX_INSTALLED = False
-
-EXT_MODULES = [
-    ("etree",         "lxml.etree"),
-    ("objectify",     "lxml.objectify"),
-    ("pyclasslookup", "lxml.pyclasslookup")
-    ]
+    CYTHON_INSTALLED = False
 
+EXT_MODULES = ["lxml.etree", "lxml.objectify","lxml.pyclasslookup"]
 
 def env_var(name):
     value = os.getenv(name, '')
     return value.split(os.pathsep)
 
 def ext_modules(static_include_dirs, static_library_dirs, static_cflags): 
-    if PYREX_INSTALLED:
+    if CYTHON_INSTALLED:
         source_extension = ".pyx"
     else:
-        print ("NOTE: Trying to build without Pyrex, pre-generated "
+        print ("NOTE: Trying to build without Cython, pre-generated "
                "'src/lxml/etree.c' needs to be available.")
         source_extension = ".c"
 
     if OPTION_WITHOUT_OBJECTIFY:
-        modules = [ entry for entry in EXT_MODULES if entry[0] != 'objectify' ]
+        modules = [ entry for entry in EXT_MODULES
+                    if 'objectify' not in entry[0] ]
     else:
         modules = EXT_MODULES
 
@@ -46,10 +41,10 @@ def ext_modules(static_include_dirs, static_library_dirs, static_cflags):
         runtime_library_dirs = []
     
     result = []
-    for module, package in modules:
+    for module in modules:
         result.append(
             Extension(
-            package,
+            module,
             sources = ["src/lxml/" + module + source_extension],
             extra_compile_args = ['-w'] + _cflags,
             define_macros = _define_macros,
@@ -62,7 +57,7 @@ def ext_modules(static_include_dirs, static_library_dirs, static_cflags):
 
 def extra_setup_args():
     result = {}
-    if PYREX_INSTALLED:
+    if CYTHON_INSTALLED:
         result['cmdclass'] = {'build_ext': build_pyx}
     return result
 
@@ -86,7 +81,7 @@ def library_dirs(static_library_dirs):
         return static_library_dirs
     # filter them from xslt-config --libs
     result = []
-    possible_library_dirs = flags('xslt-config --libs')
+    possible_library_dirs = flags('libs')
     for possible_library_dir in possible_library_dirs:
         if possible_library_dir.startswith('-L'):
             result.append(possible_library_dir[2:])
@@ -100,7 +95,7 @@ def include_dirs(static_include_dirs):
         return static_include_dirs
     # filter them from xslt-config --cflags
     result = []
-    possible_include_dirs = flags('xslt-config --cflags')
+    possible_include_dirs = flags('cflags')
     for possible_include_dir in possible_include_dirs:
         if possible_include_dir.startswith('-I'):
             result.append(possible_include_dir[2:])
@@ -119,7 +114,7 @@ def cflags(static_cflags):
         return result
 
     # anything from xslt-config --cflags that doesn't start with -I
-    possible_cflags = flags('xslt-config --cflags')
+    possible_cflags = flags('cflags')
     for possible_cflag in possible_cflags:
         if not possible_cflag.startswith('-I'):
             result.append(possible_cflag)
@@ -132,10 +127,40 @@ def define_macros():
     if OPTION_WITHOUT_THREADING:
         macros.append(('WITHOUT_THREADING', None))
     return macros
-    
-def flags(cmd):
-    wf, rf, ef = os.popen3(cmd)
-    return rf.read().split()
+
+def flags(option):
+    cmd = "%s --%s" % (find_xslt_config(), option)
+    try:
+        import subprocess
+    except ImportError:
+        # Python 2.3
+        _, rf, ef = os.popen3(cmd)
+    else:
+        # Python 2.4+
+        p = subprocess.Popen(cmd, shell=True,
+                             stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        rf, ef = p.stdout, p.stderr
+    errors = ef.read()
+    if errors:
+        print("ERROR: %s" % errors)
+        print("** make sure the development packages of libxml2 and libxslt are installed **\n")
+    return str(rf.read()).split()
+
+XSLT_CONFIG = None
+
+def find_xslt_config():
+    global XSLT_CONFIG
+    if XSLT_CONFIG:
+        return XSLT_CONFIG
+    option = '--with-xslt-config='
+    for arg in sys.argv:
+        if arg.startswith(option):
+            sys.argv.remove(arg)
+            XSLT_CONFIG = arg[len(option):]
+            return XSLT_CONFIG
+    else:
+        XSLT_CONFIG = 'xslt-config'
+    return XSLT_CONFIG
 
 def has_option(name):
     try:
