@@ -1,4 +1,4 @@
-﻿# -*- coding: UTF-8 -*-
+﻿# -*- coding: utf-8 -*-
 import unittest, doctest
 
 # These tests check that error handling in the Pyrex code is
@@ -6,6 +6,7 @@ import unittest, doctest
 # It is likely that if there are errors, instead of failing the code
 # will simply crash.
 
+import sys, gc
 from lxml import etree
 
 class ErrorTestCase(unittest.TestCase):
@@ -14,15 +15,30 @@ class ErrorTestCase(unittest.TestCase):
     def test_bad_element(self):
         # attrib argument of Element() should be a dictionary, so if
         # we pass a string we should get an error.
-        self.assertRaises(AttributeError, self.etree.Element, 'a', 'b')
+        self.assertRaises(TypeError, self.etree.Element, 'a', 'b')
 
     def test_empty_parse(self):
         self.assertRaises(etree.XMLSyntaxError, etree.fromstring, '')
 
+    def test_element_cyclic_gc_none(self):
+        # test if cyclic reference can crash etree
+        Element = self.etree.Element
+        gc.collect()
+
+        count = sys.getrefcount(None)
+
+        l = [Element('name'), Element('name')]
+        l.append(l)
+
+        del l
+        gc.collect()
+
+        self.assertEquals(sys.getrefcount(None), count)
+
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTests([unittest.makeSuite(ErrorTestCase)])
     return suite
 
 if __name__ == '__main__':
-    unittest.main()
+    print 'to test use test.py %s' % __file__
